==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/src/app/app.component.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy, OnInit, ViewContainerRef} from "@angular/core";
import {trigger, style, animate, transition, query, group} from "@angular/animations";
import {
    RepetierServer,
    ConnectionHandler,
    ServerAction,
    PrintersState,
    PrinterState,
    ServerState,
    WifiState, MessagesAction,
    RepetierState
} from "binding";
import {RSModal} from "front-ui";
import {select} from "@angular-redux/store";
import {Observable, SubscriptionLike as ISubscription} from "rxjs";
import {Router, RouterOutlet} from "@angular/router";
import {MessageState} from "binding";
import * as momentImported from 'moment'; const moment = momentImported;

@Component({
    selector: "rs-root",
    template: `<div [@routeAnimations]="prepareRoute(outlet)" ><router-outlet #outlet="outlet"></router-outlet></div>`,
    animations: [
        trigger("routeAnimations", [
            transition("* <=> *", [
                query(":enter", [
                    style({opacity: 0})
                ], {optional: true}),
                group([
                    query(":leave", [
                        animate("200ms ease-out", style({opacity: 0}))
                    ], {optional: true}),
                    query(":enter", [
                        animate("200ms ease-out", style({opacity: 1}))
                    ], {optional: true})
                ]),
            ]),
        ])
    ]
})
export class AppComponent implements OnInit, OnDestroy {
    title = "Touchscreen";
    @select("printers") printers$: Observable<PrintersState>;
    @select("server") server$: Observable<ServerState>;
    @select("wifi") wifi$: Observable<WifiState>;
    @select("messages") messages$: Observable<MessageState[]>;
    messages: MessageState[];
    private messagesSubscription: ISubscription;
    private printersSubscription: ISubscription;
    private serverSubscription: ISubscription;
    private wifiSubscription: ISubscription;
    printer: PrinterState;
    wifi: WifiState = undefined;
    serverState: ServerState = undefined;
    screenTimer: any = undefined;
    screenTimeout = -1;
    screenHidden = false;
    screenEnergySavingInitalized = false;
    initScreenLocked = false;
    messageSize = -1;
    lastMessage: any = undefined;

    constructor(private server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                public router: Router,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction,
                private messagesAction: MessagesAction) {
        RSModal.defaultView = view;
        this.serverAction.initSetting("frontSetting", {
            "goWebInterface": false,
            "language": "en",
            "listPerPage": 10,
            "listSort": 0,
            "listType": 0,
            "showEmergency": true,
            "showFullscreen": false,
            "unlockPin": "",
            "lockOnScreensaver": false
        });
        this.serverAction.initSetting("screensaver", {timeout: 10, energySaving: true});
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                const next = p.printers[p.active];
                let showStatus = false;
                if (this.printer && this.printer.slug === next.slug && next.printing && !this.printer.printing) {
                    showStatus = true;
                }
                this.printer = next;
                if (showStatus) {
                    this.router.navigateByUrl("/print-status");
                }
            } else {
                this.printer = undefined;
            }
        });
        this.serverSubscription = this.server$.subscribe((s: ServerState) => {
            const last = this.serverState;
            this.serverState = s;
            if (s.settings && s.settings["screensaver"] && s.settings["screensaver"].timeout !== this.screenTimeout) {
                this.screenTimeout = s.settings["screensaver"].timeout;
                this.initEnergySaving();
                this.resetScreensaver();
            }
            if (!this.initScreenLocked && this.serverState.settings["frontSetting"] && this.serverState.settings["frontSetting"].unlockPin && this.router.url.indexOf("unlock") === -1) {
                this.initScreenLocked = true;
                this.router.navigateByUrl("/unlock");
            }
            if (!last || last.settings.touchTime !== this.serverState.settings.touchTime) { // set locale
                moment.locale(this.serverState.settings.touchTime);
            }
        });
        this.wifiSubscription = this.wifi$.subscribe((w: WifiState) => {
            this.wifi = w;
            this.initEnergySaving();
        });
        this.messagesSubscription = this.messages$.subscribe(m => {
            this.messages = m;
            if (this.messageSize < 0) {
                return;
            }
            if (this.messages.length > this.messageSize) {
                const newMsg = this.messages[this.messages.length - 1];
                if (newMsg.slug === this.printer.slug && this.printer.printing) {
                    if (this.lastMessage) {
                        modal.hide(this.lastMessage);
                        this.lastMessage = undefined;
                    }
                    /* if (newMsg.msg.toUpperCase().indexOf("JAM") !== -1) {
                        this.lastMessage = modal.confirm("<?php _('Message') ?>", newMsg.msg, {
                            yes: "<?php _('Change Filament') ?>",
                            no: "<?php _('Close') ?>"
                        });
                        this.lastMessage.then(() => {
                            this.lastMessage = undefined;
                            this.router.navigateByUrl("/changefilament");
                        }, () => {
                            this.lastMessage = undefined;
                        });
                    } else { */
                        this.lastMessage = modal.message("<?php _('Message') ?>", newMsg.msg, {});
                        this.lastMessage.then(() => {
                            this.lastMessage = undefined;
                        }, () => {
                            this.lastMessage = undefined;
                        });
                    // }
                }
            }
            this.messageSize = m.length;
        });
        setTimeout(() => {
            this.messageSize = 0;
        }, 5000);
        window.document.body.addEventListener("mousemove", this.resetScreensaver);
        document.getElementById("screensaver").addEventListener("click", this.disableScreensaver);
    }

    prepareRoute(outlet: RouterOutlet) {
        if (this.serverState.settings && this.serverState.settings["gui"] && this.serverState.settings["gui"].noAnimation) {
            return false;
        }
        return outlet && outlet.activatedRouteData && outlet.activatedRouteData["animation"];
    }

    initEnergySaving() {
        if (this.screenEnergySavingInitalized || !this.wifi || this.screenTimeout < 0 || !this.wifi.screensaver) {
            return;
        }
        this.screenEnergySavingInitalized = true;
        if (this.screenTimeout === 0 || !this.serverState.settings["screensaver"].energySaving) {
            this.connectionHandler.send("screensaver", {enable: 0, timeout: 0});
        } else {
            this.connectionHandler.send("screensaver", {enable: 1, timeout: this.screenTimeout * 60 + 10});
        }
    }

    triggerScreensaver = () => {
        this.screenTimer = undefined;
        this.screenHidden = true;
        this.connectionHandler.send("setScreensaver", {on: true});
        document.getElementById("screensaver").style.display = "block";
        if (this.serverState.settings["frontSetting"].lockOnScreensaver && this.serverState.settings["frontSetting"].unlockPin !== "" && this.router.url.indexOf("unlock") === -1 && !this.serverState.screenLocked) {
            this.router.navigateByUrl("/unlock");
        }
    }

    disableScreensaver = (event: MouseEvent) => {
        if (this.screenHidden) {
            this.screenHidden = false;
            this.connectionHandler.send("setScreensaver", {on: false});
            document.getElementById("screensaver").style.display = "none";
            this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
        }
        event.stopPropagation();
    }

    resetScreensaver = () => {
        if (this.screenHidden) {
            return;
        }
        if (this.screenTimer) {
            window.clearTimeout(this.screenTimer);
        }
        if (this.screenTimeout <= 0) {
            return;
        } // disabled
        this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
    }

    ngOnInit() {
        this.connectionHandler.connectFrontend();
        this.resetScreensaver();
    }

    ngOnDestroy() {
        document.getElementById("screensaver").removeEventListener("click", this.disableScreensaver);
        window.document.body.removeEventListener("mousemove", this.resetScreensaver);
        this.printersSubscription.unsubscribe();
        this.wifiSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
        this.messagesSubscription.unsubscribe();
        this.connectionHandler.close();
        this.server.dispose();
    }
}

==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/src/app/app.component.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy, OnInit, ViewContainerRef} from "@angular/core";
import {trigger, style, animate, transition, query, group} from "@angular/animations";
import {
    RepetierServer,
    ConnectionHandler,
    ServerAction,
    PrintersState,
    PrinterState,
    ServerState,
    WifiState, MessagesAction,
    RepetierState
} from "binding";
import {RSModal} from "front-ui";
import {select} from "@angular-redux/store";
import {Observable, SubscriptionLike as ISubscription} from "rxjs";
import {Router, RouterOutlet} from "@angular/router";
import {MessageState} from "binding";
import * as momentImported from 'moment'; const moment = momentImported;

@Component({
    selector: "rs-root",
    template: `<div [@routeAnimations]="prepareRoute(outlet)" ><router-outlet #outlet="outlet"></router-outlet></div>`,
    animations: [
        trigger("routeAnimations", [
            transition("* <=> *", [
                query(":enter", [
                    style({opacity: 0})
                ], {optional: true}),
                group([
                    query(":leave", [
                        animate("200ms ease-out", style({opacity: 0}))
                    ], {optional: true}),
                    query(":enter", [
                        animate("200ms ease-out", style({opacity: 1}))
                    ], {optional: true})
                ]),
            ]),
        ])
    ]
})
export class AppComponent implements OnInit, OnDestroy {
    title = "Touchscreen";
    @select("printers") printers$: Observable<PrintersState>;
    @select("server") server$: Observable<ServerState>;
    @select("wifi") wifi$: Observable<WifiState>;
    @select("messages") messages$: Observable<MessageState[]>;
    messages: MessageState[];
    private messagesSubscription: ISubscription;
    private printersSubscription: ISubscription;
    private serverSubscription: ISubscription;
    private wifiSubscription: ISubscription;
    printer: PrinterState;
    wifi: WifiState = undefined;
    serverState: ServerState = undefined;
    screenTimer: any = undefined;
    screenTimeout = -1;
    screenHidden = false;
    screenEnergySavingInitalized = false;
    initScreenLocked = false;
    messageSize = -1;
    lastMessage: any = undefined;

    constructor(private server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                public router: Router,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction,
                private messagesAction: MessagesAction) {
        RSModal.defaultView = view;
        this.serverAction.initSetting("frontSetting", {
            "goWebInterface": false,
            "language": "en",
            "listPerPage": 10,
            "listSort": 0,
            "listType": 0,
            "showEmergency": true,
            "showFullscreen": false,
            "unlockPin": "",
            "lockOnScreensaver": false,
            "autopopupMessages": false
        });
        this.serverAction.initSetting("screensaver", {timeout: 10, energySaving: true});
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                const next = p.printers[p.active];
                let showStatus = false;
                if (this.printer && this.printer.slug === next.slug && next.printing && !this.printer.printing) {
                    showStatus = true;
                }
                this.printer = next;
                if (showStatus) {
                    this.router.navigateByUrl("/print-status");
                }
            } else {
                this.printer = undefined;
            }
        });
        this.serverSubscription = this.server$.subscribe((s: ServerState) => {
            const last = this.serverState;
            this.serverState = s;
            if (s.settings && s.settings["screensaver"] && s.settings["screensaver"].timeout !== this.screenTimeout) {
                this.screenTimeout = s.settings["screensaver"].timeout;
                this.initEnergySaving();
                this.resetScreensaver();
            }
            if (!this.initScreenLocked && this.serverState.settings["frontSetting"] && this.serverState.settings["frontSetting"].unlockPin && this.router.url.indexOf("unlock") === -1) {
                this.initScreenLocked = true;
                this.router.navigateByUrl("/unlock");
            }
            if (!last || last.settings.touchTime !== this.serverState.settings.touchTime) { // set locale
                moment.locale(this.serverState.settings.touchTime);
            }
        });
        this.wifiSubscription = this.wifi$.subscribe((w: WifiState) => {
            this.wifi = w;
            this.initEnergySaving();
        });
        this.messagesSubscription = this.messages$.subscribe(m => {
            this.messages = m;
            if (this.messageSize < 0) {
                return;
            }
            if (this.messages.length > this.messageSize) {
                const newMsg = this.messages[this.messages.length - 1];
                if (newMsg.slug === this.printer.slug && this.printer.printing && this.serverState.settings["frontSetting"].autopopupMessages) {
                    if (this.lastMessage) {
                        modal.hide(this.lastMessage);
                        this.lastMessage = undefined;
                    }
                    /* if (newMsg.msg.toUpperCase().indexOf("JAM") !== -1) {
                        this.lastMessage = modal.confirm("<?php _('Message') ?>", newMsg.msg, {
                            yes: "<?php _('Change Filament') ?>",
                            no: "<?php _('Close') ?>"
                        });
                        this.lastMessage.then(() => {
                            this.lastMessage = undefined;
                            this.router.navigateByUrl("/changefilament");
                        }, () => {
                            this.lastMessage = undefined;
                        });
                    } else { */
                        this.lastMessage = modal.message("<?php _('Message') ?>", newMsg.msg, {});
                        this.lastMessage.then(() => {
                            this.lastMessage = undefined;
                        }, () => {
                            this.lastMessage = undefined;
                        });
                    // }
                }
            }
            this.messageSize = m.length;
        });
        setTimeout(() => {
            this.messageSize = 0;
        }, 5000);
        window.document.body.addEventListener("mousemove", this.resetScreensaver);
        document.getElementById("screensaver").addEventListener("click", this.disableScreensaver);
    }

    prepareRoute(outlet: RouterOutlet) {
        if (this.serverState.settings && this.serverState.settings["gui"] && this.serverState.settings["gui"].noAnimation) {
            return false;
        }
        return outlet && outlet.activatedRouteData && outlet.activatedRouteData["animation"];
    }

    initEnergySaving() {
        if (this.screenEnergySavingInitalized || !this.wifi || this.screenTimeout < 0 || !this.wifi.screensaver) {
            return;
        }
        this.screenEnergySavingInitalized = true;
        if (this.screenTimeout === 0 || !this.serverState.settings["screensaver"].energySaving) {
            this.connectionHandler.send("screensaver", {enable: 0, timeout: 0});
        } else {
            this.connectionHandler.send("screensaver", {enable: 1, timeout: this.screenTimeout * 60 + 10});
        }
    }

    triggerScreensaver = () => {
        this.screenTimer = undefined;
        this.screenHidden = true;
        this.connectionHandler.send("setScreensaver", {on: true});
        document.getElementById("screensaver").style.display = "block";
        if (this.serverState.settings["frontSetting"].lockOnScreensaver && this.serverState.settings["frontSetting"].unlockPin !== "" && this.router.url.indexOf("unlock") === -1 && !this.serverState.screenLocked) {
            this.router.navigateByUrl("/unlock");
        }
    }

    disableScreensaver = (event: MouseEvent) => {
        if (this.screenHidden) {
            this.screenHidden = false;
            this.connectionHandler.send("setScreensaver", {on: false});
            document.getElementById("screensaver").style.display = "none";
            this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
        }
        event.stopPropagation();
    }

    resetScreensaver = () => {
        if (this.screenHidden) {
            return;
        }
        if (this.screenTimer) {
            window.clearTimeout(this.screenTimer);
        }
        if (this.screenTimeout <= 0) {
            return;
        } // disabled
        this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
    }

    ngOnInit() {
        this.connectionHandler.connectFrontend();
        this.resetScreensaver();
    }

    ngOnDestroy() {
        document.getElementById("screensaver").removeEventListener("click", this.disableScreensaver);
        window.document.body.removeEventListener("mousemove", this.resetScreensaver);
        this.printersSubscription.unsubscribe();
        this.wifiSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
        this.messagesSubscription.unsubscribe();
        this.connectionHandler.close();
        this.server.dispose();
    }
}
